package WebGUI::i18n::English::ShipDriver;

use strict;

our $I18N = {

	'label' => {
		message => q|Label|,
		lastUpdated => 1203569535,
		context => q|The name of a ShipDriver, supplied by the user.|,
	},

	'label help' => {
		message => q|A name for your Shipping Driver.  Choose something clear, easy to understand, and less than 100 characters.|,
		lastUpdated => 1203569511,
	},

	'enabled' => {
		message => q|Enabled?|,
		lastUpdated => 1203569584,
		context => q|Whether something can or cannot be used.|,
	},

	'enabled help' => {
		message => q|Will people using commerce on your site be able to use this Shipping Driver?|,
		lastUpdated => 1203569582,
	},

    'who can use' => {
        message => q|Group to use this shipping driver|,
        lastUpdate => 0,
        context => q|Label for the group to use option.|,
    },

    'who can use help' => {
        message => q|Specifies which group is allowed to use this shipping driver.|,
        lastUpdated => 0,
        context => q|Hover help for the group to use option.|,
    },

};

1;
